@@ -2100,6 +2100,34 @@ class Confluence(AtlassianRestAPI):
 
         return response
 
+    def get_user_details_by_accountid(self, accountid, expand=None):
+        """
+        Get information about a user through accountid
+        :param accountid: The account id
+        :param expand: OPTIONAL expand for get status of user.
+                Possible param is "status". Results are "Active, Deactivated"
+        :return: Returns the user details
+        """
+        url = "rest/api/user"
+        params = {"accountId": accountid}
+        if expand:
+            params["expand"] = expand
+
+        try:
+            response = self.get(url, params=params)
+        except HTTPError as e:
+            if e.response.status_code == 403:
+                raise ApiPermissionError("The calling user does not have permission to view users", reason=e)
+            if e.response.status_code == 404:
+                raise ApiNotFoundError(
+                    "The user with the given account does not exist",
+                    reason=e,
+                )
+
+            raise
+
+        return response
+
     def get_user_details_by_userkey(self, userkey, expand=None):
         """
         Get information about a user through user key
